@@ -15,14 +15,12 @@ function(J,H=1,main=c("LC","same","Rasch"),
       S = length(X); ncov = 1
       covnames = "X1"
       X = array(X,c(S,1,J))
-    }
-    if(is.matrix(X)){
+    }else if(is.matrix(X)){
       S = nrow(X); ncov = ncol(X)
       covnames = colnames(X)
       if(is.null(covnames)) covnames = paste("X",1:ncov,sep="")
       X = array(X,c(S,ncov,J))
-    }
-    if(is.array(X)){
+    }else{
       S = dim(X)[1]; ncov = dim(X)[2]
       covnames = colnames(X)
       if(is.null(covnames)) covnames = paste("X",1:ncov,sep="")
@@ -138,7 +136,8 @@ function(J,H=1,main=c("LC","same","Rasch"),
       if(main=="LC") Tmp1 = tmp%x%Main
       if(main=="same") Tmp1 = tmp%x%as.matrix(rowSums(Main))
       if(main=="Rasch") Tmp1 = cbind(rep(1,2^J)%o%c(tmp[-1]),Main)
-# covariate effects
+      if(main=="Rasch") Tmp1 = cbind(rowSums(Main)%o%c(tmp[-1]),Main)
+      # covariate effects
       Tmp2 = NULL
       if(ncov>0){
         Xs = matrix(X[s,,],ncov,J)
